@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0600';
 
 use Moo;
 use strictures 2;
@@ -121,7 +121,8 @@ sub BUILD {
         my @item = split /\s+/, $item, 2;
         next unless defined $item[1];
         next if $item[0] eq 'PPI::Token::Comment'
-            or $item[0] eq 'PPI::Token::Pod';
+            or $item[0] eq 'PPI::Token::Pod'
+            or $item[0] eq 'PPI::Token::End';
         push @{ $halstead{ $item[0] } }, $item[1];
     }
 #use Data::Dumper;warn(__PACKAGE__,' ',__LINE__,' ',Dumper\%halstead);
@@ -198,10 +199,10 @@ sub dump {
 
 sub _is_operand {
     my $key = shift;
-    return $key eq 'PPI::Token::Number'
+    return $key =~ /Number/
         || $key eq 'PPI::Token::Symbol'
-        || $key eq 'PPI::Token::Pod'
         || $key eq 'PPI::Token::HereDoc'
+        || $key eq 'PPI::Token::Data'
         || $key =~ /Quote/;
 }
 
@@ -224,7 +225,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0502
+version 0.0600
 
 =head1 SYNOPSIS
 
